import { useState } from "react";
import { Button, ButtonGroup, Dropdown } from "react-bootstrap";
import "./form.css";
import "./style.css";
import ge from "./image/german.png";
import fr from "./image/france.png";
import es from "./image/spain.png";
import en from "./image/london.png";
import ru from "./image/russia.png";

const App = () => {
  const [selectedItem, setSelectedItem] = useState(null);
  const [searchTerm, setSearchTerm] = useState("");

  const languageFlags = {
    English: en,
    German: ge,
    France: fr,
    Spanish: es,
    Russian: ru,
  };

  const handleDropdownSelect = (eventKey, event) => {
    setSelectedItem(eventKey);
  };

  const filteredOptions = Object.keys(languageFlags).filter((language) =>
    language.toLowerCase().startsWith(searchTerm.toLowerCase())
  );

  return (
    <div className="phppot-container">
      <h1 className="mb-5">React Bootstrap Dropdown with AutoComplete Search</h1>
      <ButtonGroup>
        <Button variant="warning">Select Language</Button>
        <Dropdown as={ButtonGroup} onSelect={handleDropdownSelect}>
          <Dropdown.Toggle split variant="warning" className="custom-split-toggle" />
          <Dropdown.Menu className="custom-dropdown-menu">
            <input
              type="text"
              placeholder="Search..."
              onChange={(e) => setSearchTerm(e.target.value)}
              style={{ margin: "8px 10px", width: "calc(100% - 20px)", borderRadius: "5px" }}
            />
            {filteredOptions.map((language) => (
              <Dropdown.Item key={language} eventKey={language}>
                {language}
              </Dropdown.Item>
            ))}
          </Dropdown.Menu>
        </Dropdown>
      </ButtonGroup>
      {selectedItem && (
        <div style={{ marginTop: "10px", marginLeft: "5px" }}>
          <span style={{ marginRight: "5px" }}>Selected Language: </span>
          <img
            src={languageFlags[selectedItem]}
            alt={`${selectedItem} flag`}
            style={{ height: "20px", marginRight: "5px" }}
          />
          {selectedItem}
        </div>
      )}
    </div>
  );
};
export default App;